<template>
    <main class="container py-4">
        <span class="d-block mb-5">Home/My Courses/{{ courseData?.title }}</span>
        <section v-if="canView" class="row">
            <section class="col-6">
                <h3 class="mb-4">{{ courseData?.title }}</h3>
                <video v-if="contentData.type == 'video'" :src="contentData?.media" width="100%" controls
                    autoplay></video>
                <div v-if="contentData.type == 'audio'"
                    class="border border-primary text-center px-4 pb-4 pt-5 rounded mb-5">
                    <i class="bi bi-mic display-1 rounded-circle border px-3 text-primary"></i>
                    <p class="mt-3 fs-4 col-8 mx-auto my-4 pt-4">{{ contentData?.title }}.{{ contentData?.file_extension
                        }}</p>
                    <audio :src="contentData.media" controls class="w-100"></audio>
                </div>
                <div v-if="contentData.type == 'image'">
                    <img :src="contentData?.media" width="100%" class="mb-3">
                    <a :href="contentData?.media" download class="btn btn-sm btn-primary me-2">Download image <i
                            class="bi bi-download ms-1"></i></a>
                    <router-link :to="contentData?.media" target="_blank" class="btn btn-sm btn-outline-primary">View in
                        full size <i class="bi bi-box-arrow-up-right ms-2"></i></router-link>
                </div>
                <div v-if="contentData.type == 'document'" class="text-center border border-primary rounded py-5 mb-5">
                    <i class="bi bi-file-earmark-text display-1 rounded-circle border px-3 text-primary"></i>
                    <p class="mt-3 fs-4 col-8 mx-auto">{{ contentData?.title }}.{{ contentData?.file_extension }}</p>
                    <a :href="contentData?.media" download="" target="_blank" class="btn btn-sm btn-primary">Download
                        Document <i class="bi bi-download ms-1"></i></a>
                </div>
            </section>
            <section class="col-6">
                <CourseLessons :chapters="chapterData" :courseId="courseData?.id" :canView="canView" />
            </section>
        </section>
        <section v-else>
            <div class="text-center text-muted">
                <i class="bi bi-emoji-frown display-5"></i>
                <p class="mb-0 mt-3">Content not available</p>
            </div>
        </section>
    </main>
</template>

<style lang="scss" scoped>
.course-preview {
    height: 400px;
    background-size: cover;
    background-position: center;
    background-repeat: no-repeat;
    border-radius: 1rem;
    display: flex;
    align-items: center;
    justify-content: center;
    color: #fff;
    font-size: 2rem;
    font-weight: bold;

    .play-btn {
        cursor: pointer;
        border: 5px solid #ffffffbd;
        border-radius: 50%;
    }
}
</style>

<script setup>
import CourseLessons from '../components/CourseLessons.vue';
import { onMounted, ref, watch } from 'vue';
import { useRoute } from 'vue-router';
import { useAuthStore } from '@/stores/auth';

const route = useRoute()
const courseId = ref(route.params.course_id)
const contentId = ref(route.query.content_id)

let canView = ref(null);
let courseData = ref({})
let contentData = ref({})
let chapterData = ref({})

watch(() => route.query.content_id, () => {
    contentId.value = route.query.content_id
    fetchContent(contentId.value)
})

onMounted(() => {
    fetchCourse()
})

// Fetch course
const fetchCourse = async () => {
    try {
        const response = await axios.get(`/course/show/${courseId.value}`, {
            headers: {
                'Content-Type': 'application/json',
                'Accept': 'application/json'
            }
        })

        courseData.value = response.data.data.course
        chapterData.value = response.data.data.chapters
        contentId.value = response.data.data.chapters[0].contents[0].id
        fetchContent(contentId.value)
    } catch (error) {
        console.log('Error fetching course data:', error);
    }
}

const fetchContent = async (contentId) => {
    try {
        const response = await axios.post(`/view_content/${contentId}`, null, {
            headers: {
                'Content-Type': 'application/json',
                'Accept': 'application/json',
                'Authorization': 'Bearer ' + useAuthStore().authToken
            }
        })

        contentData.value = response.data.data.content
        canView.value = true
    } catch (error) {
        canView.value = false
    }
}
</script>
